@@ -1,5 +1,6 @@
 import logging
 from datetime import datetime
+from logging.config import dictConfig
 
 from elasticsearch import Elasticsearch
 from .config import es_url
@@ -51,4 +52,38 @@ def add_timestamp_field(error):
     epoch = error["timeStamp"]
     epoch_short = eval((str(epoch)[:10]))
     error["@timestamp"] = datetime.fromtimestamp(epoch_short).isoformat()
-    return error
\ No newline at end of file
+    return error
+
+
+# Log config
+dictConfig({
+    'version': 1,
+    'formatters': {'default': {
+        'format': '[%(asctime)s] {%(filename)s:%(lineno)d} %(threadName)s %(levelname)s in %(module)s: %(message)s',
+    }},
+    'handlers': {
+        'info': {
+            'class': 'logging.FileHandler',
+            'level': 'DEBUG',
+            'formatter': 'default',
+            'filename': 'info.log'
+        },
+        'console': {
+            'class': 'logging.StreamHandler',
+            'level': 'DEBUG',
+            'formatter': 'default',
+            'stream': 'ext://sys.stdout',
+        }
+    },
+    'loggers': {
+        'file': {
+            'level': 'DEBUG',
+            'handlers': ['info', 'console'],
+            'propagate': ''
+        }
+    },
+    'root': {
+        'level': 'DEBUG',
+        'handlers': ['info', 'console']
+    }
+})
\ No newline at end of file
